// 加载环境变量
const dotenv = require('dotenv');
const path = require('path');

// 加载环境变量
dotenv.config();

const express = require('express');
const cors = require('cors');
const reportRoutes = require('./routes/report');

const app = express();

// 中间件
app.use(cors());
app.use(express.json());

// 静态文件服务
app.use(express.static(path.join(__dirname, 'public')));

// 路由
app.use('/api/report', reportRoutes);

// 添加模板预览路由
app.get('/preview-template', (req, res) => {
    res.sendFile(path.join(__dirname, 'public/templates/report-template.html'));
});

// 错误处理中间件
app.use((err, req, res, next) => {
    console.error(err.stack);
    res.status(500).json({
        success: false,
        message: '服务器内部错误'
    });
});

const PORT = process.env.PORT || 3000;
app.listen(PORT, () => {
    console.log(`服务器运行在端口 ${PORT}`);
    console.log(`API基础地址: ${process.env.API_BASE_URL}`);
});